# IO.Swagger - the C# library for the Weather Source Location API

Geospatial metadata for latitude/longitude points, ZIP/Postal Codes, Designated Market Areas, and OnPoint™ points. The Weather Source Location API is built upon the [OnPoint™ Platform](https://weathersource.com/products/onpoint-platform/) which ensures data that is gap-free, homogeneous, and ready for immediate analysis. We offer the highest resolution grid on the market, covering every landmass in the world and up to 200 miles offshore.  If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). 

This C# SDK is automatically generated by the [Swagger Codegen](https://github.com/swagger-api/swagger-codegen) project:

- API version: 2.0.0
- SDK version: 1.0.0
- Build package: io.swagger.codegen.v3.generators.dotnet.CSharpClientCodegen
    For more information, please visit [https://developer.weathersourceapis.com/](https://developer.weathersourceapis.com/)

<a name="frameworks-supported"></a>
## Frameworks supported
- .NET 4.0 or later
- Windows Phone 7.1 (Mango)

<a name="dependencies"></a>
## Dependencies
- [RestSharp](https://www.nuget.org/packages/RestSharp) - 105.1.0 or later
- [Json.NET](https://www.nuget.org/packages/Newtonsoft.Json/) - 7.0.0 or later
- [JsonSubTypes](https://www.nuget.org/packages/JsonSubTypes/) - 1.2.0 or later

The DLLs included in the package may not be the latest version. We recommend using [NuGet](https://docs.nuget.org/consume/installing-nuget) to obtain the latest version of the packages:
```
Install-Package RestSharp
Install-Package Newtonsoft.Json
Install-Package JsonSubTypes
```

NOTE: RestSharp versions greater than 105.1.0 have a bug which causes file uploads to fail. See [RestSharp#742](https://github.com/restsharp/RestSharp/issues/742)

<a name="installation"></a>
## Installation
Run the following command to generate the DLL
- [Mac/Linux] `/bin/sh build.sh`
- [Windows] `build.bat`

Then include the DLL (under the `bin` folder) in the C# project, and use the namespaces:
```csharp
using IO.Swagger.Api;
using IO.Swagger.Client;
using IO.Swagger.Model;
```
<a name="packaging"></a>
## Packaging

A `.nuspec` is included with the project. You can follow the Nuget quickstart to [create](https://docs.microsoft.com/en-us/nuget/quickstart/create-and-publish-a-package#create-the-package) and [publish](https://docs.microsoft.com/en-us/nuget/quickstart/create-and-publish-a-package#publish-the-package) packages.

This `.nuspec` uses placeholders from the `.csproj`, so build the `.csproj` directly:

```
nuget pack -Build -OutputDirectory out IO.Swagger.csproj
```

Then, publish to a [local feed](https://docs.microsoft.com/en-us/nuget/hosting-packages/local-feeds) or [other host](https://docs.microsoft.com/en-us/nuget/hosting-packages/overview) and consume the new package via Nuget as usual.

<a name="getting-started"></a>
## Getting Started

```csharp
using System;
using System.Diagnostics;
using IO.Swagger.Api;
using IO.Swagger.Client;
using IO.Swagger.Model;

namespace Example
{
    public class Example
    {
        public void main()
        {
            // Configure API key authorization: ApiKeyAuth
            Configuration.Default.ApiKey.Add("X-API-KEY", "YOUR_API_KEY");
            // Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
            // Configuration.Default.ApiKeyPrefix.Add("X-API-KEY", "Bearer");

            var apiInstance = new DmasApi();
            var dmaId = 56;  // int? | A [Designated Market Area ID](https://developer.weathersourceapis.com/apis/supported-dmas/).

            try
            {
                // DMA geographical metadata
                DmaObj result = apiInstance.DmasDmaIdGet(dmaId);
                Debug.WriteLine(result);
            }
            catch (Exception e)
            {
                Debug.Print("Exception when calling DmasApi.DmasDmaIdGet: " + e.Message );
            }
        }
    }
}
```

<a name="documentation-for-api-endpoints"></a>
## Documentation for API Endpoints

All URIs are relative to *https://location.weathersourceapis.com/v2*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*DmasApi* | [**DmasDmaIdGet**](docs/DmasApi.md#dmasdmaidget) | **GET** /dmas/{dmaId} | DMA geographical metadata
*OnpointsApi* | [**OnpointsOnpointIdGet**](docs/OnpointsApi.md#onpointsonpointidget) | **GET** /onpoints/{onpointId} | OnPoint™ point geographical metadata
*PointsApi* | [**PointsLatitudelongitudeGet**](docs/PointsApi.md#pointslatitudelongitudeget) | **GET** /points/{latitude},{longitude} | Latitude/Longitude geographical metadata
*PostcodesApi* | [**PostcodesPostcodecountryCodeGet**](docs/PostcodesApi.md#postcodespostcodecountrycodeget) | **GET** /postcodes/{postcode},{countryCode} | Postcode geographical metadata

<a name="documentation-for-models"></a>
## Documentation for Models

 - [Model.BoundingPoints](docs/BoundingPoints.md)
 - [Model.BoundingPointsInner](docs/BoundingPointsInner.md)
 - [Model.CountryCode](docs/CountryCode.md)
 - [Model.CountryName](docs/CountryName.md)
 - [Model.Distance](docs/Distance.md)
 - [Model.DistancePop](docs/DistancePop.md)
 - [Model.DmaId](docs/DmaId.md)
 - [Model.DmaName](docs/DmaName.md)
 - [Model.DmaObj](docs/DmaObj.md)
 - [Model.ErrorObj](docs/ErrorObj.md)
 - [Model.Grid](docs/Grid.md)
 - [Model.Latitude](docs/Latitude.md)
 - [Model.Longitude](docs/Longitude.md)
 - [Model.OnpointId](docs/OnpointId.md)
 - [Model.OnpointObj](docs/OnpointObj.md)
 - [Model.PointObj](docs/PointObj.md)
 - [Model.Population](docs/Population.md)
 - [Model.Postcode](docs/Postcode.md)
 - [Model.PostcodeObj](docs/PostcodeObj.md)
 - [Model.SamplePoints](docs/SamplePoints.md)
 - [Model.SamplePointsInner](docs/SamplePointsInner.md)
 - [Model.SubdivCode](docs/SubdivCode.md)
 - [Model.SubdivName](docs/SubdivName.md)
 - [Model.Timezone](docs/Timezone.md)

<a name="documentation-for-authorization"></a>
## Documentation for Authorization

<a name="ApiKeyAuth"></a>
### ApiKeyAuth

- **Type**: API key
- **API key parameter name**: X-API-KEY
- **Location**: HTTP header

