/* 
 * Weather Source Location API
 *
 * Geospatial metadata for latitude/longitude points, ZIP/Postal Codes, Designated Market Areas, and OnPoint™ points. The Weather Source Location API is built upon the [OnPoint™ Platform](https://weathersource.com/products/onpoint-platform/) which ensures data that is gap-free, homogeneous, and ready for immediate analysis. We offer the highest resolution grid on the market, covering every landmass in the world and up to 200 miles offshore.  If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). 
 *
 * OpenAPI spec version: 2.0.0
 * Contact: support@weathersource.com
 * Generated by: https://github.com/swagger-api/swagger-codegen.git
 */
using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using RestSharp;
using IO.Swagger.Client;
using IO.Swagger.Model;

namespace IO.Swagger.Api
{
    /// <summary>
    /// Represents a collection of functions to interact with the API endpoints
    /// </summary>
        public interface IPostcodesApi : IApiAccessor
    {
        #region Synchronous Operations
        /// <summary>
        /// Postcode geographical metadata
        /// </summary>
        /// <remarks>
        /// Returns geographical metadata for a postcode
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="postcode">A postcode string.</param>
        /// <param name="countryCode">An uppercase 2-character [ISO 3166-1 Alpha-2 country code](https://developer.weathersourceapis.com/apis/countries-with-postal-code-support/).</param>
        /// <returns>PostcodeObj</returns>
        PostcodeObj PostcodesPostcodecountryCodeGet (string postcode, string countryCode);

        /// <summary>
        /// Postcode geographical metadata
        /// </summary>
        /// <remarks>
        /// Returns geographical metadata for a postcode
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="postcode">A postcode string.</param>
        /// <param name="countryCode">An uppercase 2-character [ISO 3166-1 Alpha-2 country code](https://developer.weathersourceapis.com/apis/countries-with-postal-code-support/).</param>
        /// <returns>ApiResponse of PostcodeObj</returns>
        ApiResponse<PostcodeObj> PostcodesPostcodecountryCodeGetWithHttpInfo (string postcode, string countryCode);
        #endregion Synchronous Operations
        #region Asynchronous Operations
        /// <summary>
        /// Postcode geographical metadata
        /// </summary>
        /// <remarks>
        /// Returns geographical metadata for a postcode
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="postcode">A postcode string.</param>
        /// <param name="countryCode">An uppercase 2-character [ISO 3166-1 Alpha-2 country code](https://developer.weathersourceapis.com/apis/countries-with-postal-code-support/).</param>
        /// <returns>Task of PostcodeObj</returns>
        System.Threading.Tasks.Task<PostcodeObj> PostcodesPostcodecountryCodeGetAsync (string postcode, string countryCode);

        /// <summary>
        /// Postcode geographical metadata
        /// </summary>
        /// <remarks>
        /// Returns geographical metadata for a postcode
        /// </remarks>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="postcode">A postcode string.</param>
        /// <param name="countryCode">An uppercase 2-character [ISO 3166-1 Alpha-2 country code](https://developer.weathersourceapis.com/apis/countries-with-postal-code-support/).</param>
        /// <returns>Task of ApiResponse (PostcodeObj)</returns>
        System.Threading.Tasks.Task<ApiResponse<PostcodeObj>> PostcodesPostcodecountryCodeGetAsyncWithHttpInfo (string postcode, string countryCode);
        #endregion Asynchronous Operations
    }

    /// <summary>
    /// Represents a collection of functions to interact with the API endpoints
    /// </summary>
        public partial class PostcodesApi : IPostcodesApi
    {
        private IO.Swagger.Client.ExceptionFactory _exceptionFactory = (name, response) => null;

        /// <summary>
        /// Initializes a new instance of the <see cref="PostcodesApi"/> class.
        /// </summary>
        /// <returns></returns>
        public PostcodesApi(String basePath)
        {
            this.Configuration = new IO.Swagger.Client.Configuration { BasePath = basePath };

            ExceptionFactory = IO.Swagger.Client.Configuration.DefaultExceptionFactory;
        }

        /// <summary>
        /// Initializes a new instance of the <see cref="PostcodesApi"/> class
        /// </summary>
        /// <returns></returns>
        public PostcodesApi()
        {
            this.Configuration = IO.Swagger.Client.Configuration.Default;

            ExceptionFactory = IO.Swagger.Client.Configuration.DefaultExceptionFactory;
        }

        /// <summary>
        /// Initializes a new instance of the <see cref="PostcodesApi"/> class
        /// using Configuration object
        /// </summary>
        /// <param name="configuration">An instance of Configuration</param>
        /// <returns></returns>
        public PostcodesApi(IO.Swagger.Client.Configuration configuration = null)
        {
            if (configuration == null) // use the default one in Configuration
                this.Configuration = IO.Swagger.Client.Configuration.Default;
            else
                this.Configuration = configuration;

            ExceptionFactory = IO.Swagger.Client.Configuration.DefaultExceptionFactory;
        }

        /// <summary>
        /// Gets the base path of the API client.
        /// </summary>
        /// <value>The base path</value>
        public String GetBasePath()
        {
            return this.Configuration.ApiClient.RestClient.BaseUrl.ToString();
        }

        /// <summary>
        /// Sets the base path of the API client.
        /// </summary>
        /// <value>The base path</value>
        [Obsolete("SetBasePath is deprecated, please do 'Configuration.ApiClient = new ApiClient(\"http://new-path\")' instead.")]
        public void SetBasePath(String basePath)
        {
            // do nothing
        }

        /// <summary>
        /// Gets or sets the configuration object
        /// </summary>
        /// <value>An instance of the Configuration</value>
        public IO.Swagger.Client.Configuration Configuration {get; set;}

        /// <summary>
        /// Provides a factory method hook for the creation of exceptions.
        /// </summary>
        public IO.Swagger.Client.ExceptionFactory ExceptionFactory
        {
            get
            {
                if (_exceptionFactory != null && _exceptionFactory.GetInvocationList().Length > 1)
                {
                    throw new InvalidOperationException("Multicast delegate for ExceptionFactory is unsupported.");
                }
                return _exceptionFactory;
            }
            set { _exceptionFactory = value; }
        }

        /// <summary>
        /// Gets the default header.
        /// </summary>
        /// <returns>Dictionary of HTTP header</returns>
        [Obsolete("DefaultHeader is deprecated, please use Configuration.DefaultHeader instead.")]
        public IDictionary<String, String> DefaultHeader()
        {
            return new ReadOnlyDictionary<string, string>(this.Configuration.DefaultHeader);
        }

        /// <summary>
        /// Add default header.
        /// </summary>
        /// <param name="key">Header field name.</param>
        /// <param name="value">Header field value.</param>
        /// <returns></returns>
        [Obsolete("AddDefaultHeader is deprecated, please use Configuration.AddDefaultHeader instead.")]
        public void AddDefaultHeader(string key, string value)
        {
            this.Configuration.AddDefaultHeader(key, value);
        }

        /// <summary>
        /// Postcode geographical metadata Returns geographical metadata for a postcode
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="postcode">A postcode string.</param>
        /// <param name="countryCode">An uppercase 2-character [ISO 3166-1 Alpha-2 country code](https://developer.weathersourceapis.com/apis/countries-with-postal-code-support/).</param>
        /// <returns>PostcodeObj</returns>
        public PostcodeObj PostcodesPostcodecountryCodeGet (string postcode, string countryCode)
        {
             ApiResponse<PostcodeObj> localVarResponse = PostcodesPostcodecountryCodeGetWithHttpInfo(postcode, countryCode);
             return localVarResponse.Data;
        }

        /// <summary>
        /// Postcode geographical metadata Returns geographical metadata for a postcode
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="postcode">A postcode string.</param>
        /// <param name="countryCode">An uppercase 2-character [ISO 3166-1 Alpha-2 country code](https://developer.weathersourceapis.com/apis/countries-with-postal-code-support/).</param>
        /// <returns>ApiResponse of PostcodeObj</returns>
        public ApiResponse< PostcodeObj > PostcodesPostcodecountryCodeGetWithHttpInfo (string postcode, string countryCode)
        {
            // verify the required parameter 'postcode' is set
            if (postcode == null)
                throw new ApiException(400, "Missing required parameter 'postcode' when calling PostcodesApi->PostcodesPostcodecountryCodeGet");
            // verify the required parameter 'countryCode' is set
            if (countryCode == null)
                throw new ApiException(400, "Missing required parameter 'countryCode' when calling PostcodesApi->PostcodesPostcodecountryCodeGet");

            var localVarPath = "/postcodes/{postcode},{countryCode}";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (postcode != null) localVarPathParams.Add("postcode", this.Configuration.ApiClient.ParameterToString(postcode)); // path parameter
            if (countryCode != null) localVarPathParams.Add("countryCode", this.Configuration.ApiClient.ParameterToString(countryCode)); // path parameter
            // authentication (ApiKeyAuth) required
            if (!String.IsNullOrEmpty(this.Configuration.GetApiKeyWithPrefix("X-API-KEY")))
            {
                localVarHeaderParams["X-API-KEY"] = this.Configuration.GetApiKeyWithPrefix("X-API-KEY");
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) this.Configuration.ApiClient.CallApi(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("PostcodesPostcodecountryCodeGet", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<PostcodeObj>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => string.Join(",", x.Value)),
                (PostcodeObj) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(PostcodeObj)));
        }

        /// <summary>
        /// Postcode geographical metadata Returns geographical metadata for a postcode
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="postcode">A postcode string.</param>
        /// <param name="countryCode">An uppercase 2-character [ISO 3166-1 Alpha-2 country code](https://developer.weathersourceapis.com/apis/countries-with-postal-code-support/).</param>
        /// <returns>Task of PostcodeObj</returns>
        public async System.Threading.Tasks.Task<PostcodeObj> PostcodesPostcodecountryCodeGetAsync (string postcode, string countryCode)
        {
             ApiResponse<PostcodeObj> localVarResponse = await PostcodesPostcodecountryCodeGetAsyncWithHttpInfo(postcode, countryCode);
             return localVarResponse.Data;

        }

        /// <summary>
        /// Postcode geographical metadata Returns geographical metadata for a postcode
        /// </summary>
        /// <exception cref="IO.Swagger.Client.ApiException">Thrown when fails to make API call</exception>
        /// <param name="postcode">A postcode string.</param>
        /// <param name="countryCode">An uppercase 2-character [ISO 3166-1 Alpha-2 country code](https://developer.weathersourceapis.com/apis/countries-with-postal-code-support/).</param>
        /// <returns>Task of ApiResponse (PostcodeObj)</returns>
        public async System.Threading.Tasks.Task<ApiResponse<PostcodeObj>> PostcodesPostcodecountryCodeGetAsyncWithHttpInfo (string postcode, string countryCode)
        {
            // verify the required parameter 'postcode' is set
            if (postcode == null)
                throw new ApiException(400, "Missing required parameter 'postcode' when calling PostcodesApi->PostcodesPostcodecountryCodeGet");
            // verify the required parameter 'countryCode' is set
            if (countryCode == null)
                throw new ApiException(400, "Missing required parameter 'countryCode' when calling PostcodesApi->PostcodesPostcodecountryCodeGet");

            var localVarPath = "/postcodes/{postcode},{countryCode}";
            var localVarPathParams = new Dictionary<String, String>();
            var localVarQueryParams = new List<KeyValuePair<String, String>>();
            var localVarHeaderParams = new Dictionary<String, String>(this.Configuration.DefaultHeader);
            var localVarFormParams = new Dictionary<String, String>();
            var localVarFileParams = new Dictionary<String, FileParameter>();
            Object localVarPostBody = null;

            // to determine the Content-Type header
            String[] localVarHttpContentTypes = new String[] {
            };
            String localVarHttpContentType = this.Configuration.ApiClient.SelectHeaderContentType(localVarHttpContentTypes);

            // to determine the Accept header
            String[] localVarHttpHeaderAccepts = new String[] {
                "application/json"
            };
            String localVarHttpHeaderAccept = this.Configuration.ApiClient.SelectHeaderAccept(localVarHttpHeaderAccepts);
            if (localVarHttpHeaderAccept != null)
                localVarHeaderParams.Add("Accept", localVarHttpHeaderAccept);

            if (postcode != null) localVarPathParams.Add("postcode", this.Configuration.ApiClient.ParameterToString(postcode)); // path parameter
            if (countryCode != null) localVarPathParams.Add("countryCode", this.Configuration.ApiClient.ParameterToString(countryCode)); // path parameter
            // authentication (ApiKeyAuth) required
            if (!String.IsNullOrEmpty(this.Configuration.GetApiKeyWithPrefix("X-API-KEY")))
            {
                localVarHeaderParams["X-API-KEY"] = this.Configuration.GetApiKeyWithPrefix("X-API-KEY");
            }

            // make the HTTP request
            IRestResponse localVarResponse = (IRestResponse) await this.Configuration.ApiClient.CallApiAsync(localVarPath,
                Method.GET, localVarQueryParams, localVarPostBody, localVarHeaderParams, localVarFormParams, localVarFileParams,
                localVarPathParams, localVarHttpContentType);

            int localVarStatusCode = (int) localVarResponse.StatusCode;

            if (ExceptionFactory != null)
            {
                Exception exception = ExceptionFactory("PostcodesPostcodecountryCodeGet", localVarResponse);
                if (exception != null) throw exception;
            }

            return new ApiResponse<PostcodeObj>(localVarStatusCode,
                localVarResponse.Headers.ToDictionary(x => x.Name, x => string.Join(",", x.Value)),
                (PostcodeObj) this.Configuration.ApiClient.Deserialize(localVarResponse, typeof(PostcodeObj)));
        }

    }
}
