/* 
 * Weather Source Location API
 *
 * Geospatial metadata for latitude/longitude points, ZIP/Postal Codes, Designated Market Areas, and OnPoint™ points. The Weather Source Location API is built upon the [OnPoint™ Platform](https://weathersource.com/products/onpoint-platform/) which ensures data that is gap-free, homogeneous, and ready for immediate analysis. We offer the highest resolution grid on the market, covering every landmass in the world and up to 200 miles offshore.  If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). 
 *
 * OpenAPI spec version: 2.0.0
 * Contact: support@weathersource.com
 * Generated by: https://github.com/swagger-api/swagger-codegen.git
 */
using System;
using System.Linq;
using System.IO;
using System.Text;
using System.Text.RegularExpressions;
using System.Collections;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Runtime.Serialization;
using Newtonsoft.Json;
using Newtonsoft.Json.Converters;
using System.ComponentModel.DataAnnotations;
using SwaggerDateConverter = IO.Swagger.Client.SwaggerDateConverter;

namespace IO.Swagger.Model
{
    /// <summary>
    /// A Designated Market Area location metadata object
    /// </summary>
    [DataContract]
        public partial class DmaObj :  IEquatable<DmaObj>, IValidatableObject
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="DmaObj" /> class.
        /// </summary>
        /// <param name="dmaId">dmaId (required).</param>
        /// <param name="dmaName">dmaName (required).</param>
        /// <param name="timezone">timezone (required).</param>
        /// <param name="population">population (required).</param>
        /// <param name="countryCode">countryCode (required).</param>
        /// <param name="countryName">countryName (required).</param>
        /// <param name="samplePoints">samplePoints (required).</param>
        /// <param name="grid">grid (required).</param>
        public DmaObj(DmaId dmaId = default(DmaId), DmaName dmaName = default(DmaName), Timezone timezone = default(Timezone), Population population = default(Population), CountryCode countryCode = default(CountryCode), CountryName countryName = default(CountryName), SamplePoints samplePoints = default(SamplePoints), Grid grid = default(Grid))
        {
            // to ensure "dmaId" is required (not null)
            if (dmaId == null)
            {
                throw new InvalidDataException("dmaId is a required property for DmaObj and cannot be null");
            }
            else
            {
                this.DmaId = dmaId;
            }
            // to ensure "dmaName" is required (not null)
            if (dmaName == null)
            {
                throw new InvalidDataException("dmaName is a required property for DmaObj and cannot be null");
            }
            else
            {
                this.DmaName = dmaName;
            }
            // to ensure "timezone" is required (not null)
            if (timezone == null)
            {
                throw new InvalidDataException("timezone is a required property for DmaObj and cannot be null");
            }
            else
            {
                this.Timezone = timezone;
            }
            // to ensure "population" is required (not null)
            if (population == null)
            {
                throw new InvalidDataException("population is a required property for DmaObj and cannot be null");
            }
            else
            {
                this.Population = population;
            }
            // to ensure "countryCode" is required (not null)
            if (countryCode == null)
            {
                throw new InvalidDataException("countryCode is a required property for DmaObj and cannot be null");
            }
            else
            {
                this.CountryCode = countryCode;
            }
            // to ensure "countryName" is required (not null)
            if (countryName == null)
            {
                throw new InvalidDataException("countryName is a required property for DmaObj and cannot be null");
            }
            else
            {
                this.CountryName = countryName;
            }
            // to ensure "samplePoints" is required (not null)
            if (samplePoints == null)
            {
                throw new InvalidDataException("samplePoints is a required property for DmaObj and cannot be null");
            }
            else
            {
                this.SamplePoints = samplePoints;
            }
            // to ensure "grid" is required (not null)
            if (grid == null)
            {
                throw new InvalidDataException("grid is a required property for DmaObj and cannot be null");
            }
            else
            {
                this.Grid = grid;
            }
        }
        
        /// <summary>
        /// Gets or Sets DmaId
        /// </summary>
        [DataMember(Name="dmaId", EmitDefaultValue=false)]
        public DmaId DmaId { get; set; }

        /// <summary>
        /// Gets or Sets DmaName
        /// </summary>
        [DataMember(Name="dmaName", EmitDefaultValue=false)]
        public DmaName DmaName { get; set; }

        /// <summary>
        /// Gets or Sets Timezone
        /// </summary>
        [DataMember(Name="timezone", EmitDefaultValue=false)]
        public Timezone Timezone { get; set; }

        /// <summary>
        /// Gets or Sets Population
        /// </summary>
        [DataMember(Name="population", EmitDefaultValue=false)]
        public Population Population { get; set; }

        /// <summary>
        /// Gets or Sets CountryCode
        /// </summary>
        [DataMember(Name="countryCode", EmitDefaultValue=false)]
        public CountryCode CountryCode { get; set; }

        /// <summary>
        /// Gets or Sets CountryName
        /// </summary>
        [DataMember(Name="countryName", EmitDefaultValue=false)]
        public CountryName CountryName { get; set; }

        /// <summary>
        /// Gets or Sets SamplePoints
        /// </summary>
        [DataMember(Name="samplePoints", EmitDefaultValue=false)]
        public SamplePoints SamplePoints { get; set; }

        /// <summary>
        /// Gets or Sets Grid
        /// </summary>
        [DataMember(Name="grid", EmitDefaultValue=false)]
        public Grid Grid { get; set; }

        /// <summary>
        /// Returns the string presentation of the object
        /// </summary>
        /// <returns>String presentation of the object</returns>
        public override string ToString()
        {
            var sb = new StringBuilder();
            sb.Append("class DmaObj {\n");
            sb.Append("  DmaId: ").Append(DmaId).Append("\n");
            sb.Append("  DmaName: ").Append(DmaName).Append("\n");
            sb.Append("  Timezone: ").Append(Timezone).Append("\n");
            sb.Append("  Population: ").Append(Population).Append("\n");
            sb.Append("  CountryCode: ").Append(CountryCode).Append("\n");
            sb.Append("  CountryName: ").Append(CountryName).Append("\n");
            sb.Append("  SamplePoints: ").Append(SamplePoints).Append("\n");
            sb.Append("  Grid: ").Append(Grid).Append("\n");
            sb.Append("}\n");
            return sb.ToString();
        }
  
        /// <summary>
        /// Returns the JSON string presentation of the object
        /// </summary>
        /// <returns>JSON string presentation of the object</returns>
        public virtual string ToJson()
        {
            return JsonConvert.SerializeObject(this, Formatting.Indented);
        }

        /// <summary>
        /// Returns true if objects are equal
        /// </summary>
        /// <param name="input">Object to be compared</param>
        /// <returns>Boolean</returns>
        public override bool Equals(object input)
        {
            return this.Equals(input as DmaObj);
        }

        /// <summary>
        /// Returns true if DmaObj instances are equal
        /// </summary>
        /// <param name="input">Instance of DmaObj to be compared</param>
        /// <returns>Boolean</returns>
        public bool Equals(DmaObj input)
        {
            if (input == null)
                return false;

            return 
                (
                    this.DmaId == input.DmaId ||
                    (this.DmaId != null &&
                    this.DmaId.Equals(input.DmaId))
                ) && 
                (
                    this.DmaName == input.DmaName ||
                    (this.DmaName != null &&
                    this.DmaName.Equals(input.DmaName))
                ) && 
                (
                    this.Timezone == input.Timezone ||
                    (this.Timezone != null &&
                    this.Timezone.Equals(input.Timezone))
                ) && 
                (
                    this.Population == input.Population ||
                    (this.Population != null &&
                    this.Population.Equals(input.Population))
                ) && 
                (
                    this.CountryCode == input.CountryCode ||
                    (this.CountryCode != null &&
                    this.CountryCode.Equals(input.CountryCode))
                ) && 
                (
                    this.CountryName == input.CountryName ||
                    (this.CountryName != null &&
                    this.CountryName.Equals(input.CountryName))
                ) && 
                (
                    this.SamplePoints == input.SamplePoints ||
                    (this.SamplePoints != null &&
                    this.SamplePoints.Equals(input.SamplePoints))
                ) && 
                (
                    this.Grid == input.Grid ||
                    (this.Grid != null &&
                    this.Grid.Equals(input.Grid))
                );
        }

        /// <summary>
        /// Gets the hash code
        /// </summary>
        /// <returns>Hash code</returns>
        public override int GetHashCode()
        {
            unchecked // Overflow is fine, just wrap
            {
                int hashCode = 41;
                if (this.DmaId != null)
                    hashCode = hashCode * 59 + this.DmaId.GetHashCode();
                if (this.DmaName != null)
                    hashCode = hashCode * 59 + this.DmaName.GetHashCode();
                if (this.Timezone != null)
                    hashCode = hashCode * 59 + this.Timezone.GetHashCode();
                if (this.Population != null)
                    hashCode = hashCode * 59 + this.Population.GetHashCode();
                if (this.CountryCode != null)
                    hashCode = hashCode * 59 + this.CountryCode.GetHashCode();
                if (this.CountryName != null)
                    hashCode = hashCode * 59 + this.CountryName.GetHashCode();
                if (this.SamplePoints != null)
                    hashCode = hashCode * 59 + this.SamplePoints.GetHashCode();
                if (this.Grid != null)
                    hashCode = hashCode * 59 + this.Grid.GetHashCode();
                return hashCode;
            }
        }

        /// <summary>
        /// To validate all properties of the instance
        /// </summary>
        /// <param name="validationContext">Validation context</param>
        /// <returns>Validation Result</returns>
        IEnumerable<System.ComponentModel.DataAnnotations.ValidationResult> IValidatableObject.Validate(ValidationContext validationContext)
        {
            yield break;
        }
    }
}
